#
# Run with: rpm -bb binutils-rpm.pkg
#
Summary: GNU Binutils for 68HC11 and 68HC12 microcontrollers
Name: binutils-68hc1x
Version: 2.15
Release: 3.1
Copyright: GPL
Group: Development/68HC1x
Source: binutils-2.15.tar.bz2
Patch: binutils-2.15-m68hc1x-20040801.diffs
URL: http://www.gnu-m68hc11.org
Distribution: GNU/Linux
Vendor: FSF
Packager: stcarrez@nerim.fr
Buildroot: /usr/src/RPM/BUILD/releases/3.1/binutils-inst
Prefix: /usr
%description
This package contains the cross assembler, linker, archiver and 
other tools for Motorola 68HC11 and 68HC12 microcontroller.

%prep

%setup -T -c
cd ..
rmdir $RPM_PACKAGE_NAME-$RPM_PACKAGE_VERSION
tar --use-compress=bzip2 -xf $RPM_SOURCE_DIR/binutils-2.15.tar.bz2
mv binutils-2.15 $RPM_PACKAGE_NAME-$RPM_PACKAGE_VERSION
cd $RPM_PACKAGE_NAME-$RPM_PACKAGE_VERSION

%patch -p1

# Create a tar.bz2 that contains the patched sources
cd ..
tar -cjf $RPM_SOURCE_DIR/$RPM_PACKAGE_NAME-$RPM_PACKAGE_VERSION.tar.bz2 $RPM_PACKAGE_NAME-$RPM_PACKAGE_VERSION

# Configure the package
cd $RPM_PACKAGE_NAME-$RPM_PACKAGE_VERSION
export PATH=/bin:/usr/bin:$PATH
sh ./configure --target=m6811-elf --program-prefix=m6811-elf- --prefix=/usr
%build
export PATH=/bin:/usr/bin:$PATH
make CFLAGS="-Os"

#
# Format the documentation
#
cd bfd/doc
make bfd.dvi
cd ../../gas/doc
make as.dvi
/usr/local/bin/texi2html -menu -split_chapter -nosec_nav \
	  -top_file=as_doc.html -I . ./as.texinfo
cd ../../ld
ln -s ../bfd/doc/bfdsumm.texi
make ld.dvi
/usr/local/bin/texi2html -menu -split_chapter -nosec_nav \
	  -top_file=ld_doc.html -I . ./ld.texinfo
cd ../binutils/doc
make binutils.dvi
/usr/local/bin/texi2html -menu -split_chapter -nosec_nav \
	  -top_file=binutils_doc.html -I . ./binutils.texi
cd ../..

# Create and Format the Using/Tutorial Guide
mkdir guide
cp -p /opt/gnu/savannah/m68hc11-main/doc/*.texi guide/
cp -p /opt/gnu/savannah/m68hc11-main/doc/texinfo.tex guide/
cd guide
/usr/local/bin/texi2html -menu -split_chapter -nosec_nav \
          -top_file=guide.html -I . ./hc11.texi

%install
make prefix=$RPM_BUILD_ROOT/usr INSTALL=install install
strip $RPM_BUILD_ROOT/usr/bin/m6811-elf-*

#
# Install the documentation
#
mkdir -p $RPM_BUILD_ROOT/usr/m6811-elf/doc
cp -p gas/doc/as_*.html $RPM_BUILD_ROOT/usr/m6811-elf/doc
cp -p ld/ld_*.html $RPM_BUILD_ROOT/usr/m6811-elf/doc
cp -p binutils/doc/binutils_*.html $RPM_BUILD_ROOT/usr/m6811-elf/doc
cp -p guide/*.html $RPM_BUILD_ROOT/usr/m6811-elf/doc

#
# Install the glue documentation file
#
cp /opt/gnu/savannah/m68hc11-main/build/gnu-m68hc11.html $RPM_BUILD_ROOT/usr/m6811-elf/doc/index.html
cp /opt/gnu/savannah/m68hc11-main/build/floating.png $RPM_BUILD_ROOT/usr/m6811-elf/doc/floating.png
cp /opt/gnu/savannah/m68hc11-main/build/leopard.png $RPM_BUILD_ROOT/usr/m6811-elf/doc/leopard.png
cp /opt/gnu/savannah/m68hc11-main/build/savannah.css $RPM_BUILD_ROOT/usr/m6811-elf/doc/savannah.css
cp /opt/gnu/savannah/m68hc11-main/build/gnu-68hc1x-gnu.jpg $RPM_BUILD_ROOT/usr/m6811-elf/doc/gnu-68hc1x-gnu.jpg
cp /opt/gnu/savannah/m68hc11-main/build/COPYING $RPM_BUILD_ROOT/usr/m6811-elf/doc/COPYING


#
# Format the HTML man pages
#
echo "Building the HTML man pages..."

# On Mandrake 8.1, the groff is completely broken.
# Must use a local version of groff that works!
# export PATH=/usr/local/bin:$PATH
for i in $RPM_BUILD_ROOT/usr/man/man1/*; do
  case $i in
    *.1)
      iname=$i
      name=`basename $iname .1 | sed -e 's,m6811-elf-,,'`
      cat $i | /usr/bin/man2html > $RPM_BUILD_ROOT/usr/m6811-elf/doc/$name.html
      ;;

    *.bz2)
      iname=`basename $i .bz2`
      name=`basename $iname .1 | sed -e 's,m6811-elf-,,'`
      bzip2 -c -d $i | /usr/bin/man2html > $RPM_BUILD_ROOT/usr/m6811-elf/doc/$name.html
      ;;

  esac
done

%files
#%doc README
%attr(555,root,root) %dir /usr/bin
%attr(555,root,root) %dir /usr/man
%attr(555,root,root) %dir /usr/man/man1
%attr(555,root,root) %dir /usr/m6811-elf
%attr(555,root,root) %dir /usr/m6811-elf/bin
%attr(555,root,root) %dir /usr/m6811-elf/lib
%attr(555,root,root) %dir /usr/m6811-elf/lib/ldscripts
%attr(555,root,root) /usr/bin/m6811-elf-size
%attr(555,root,root) /usr/bin/m6811-elf-objdump
%attr(555,root,root) /usr/bin/m6811-elf-ar
%attr(555,root,root) /usr/bin/m6811-elf-strings
%attr(555,root,root) /usr/bin/m6811-elf-ranlib
%attr(555,root,root) /usr/bin/m6811-elf-c++filt
%attr(555,root,root) /usr/bin/m6811-elf-objcopy
%attr(555,root,root) /usr/bin/m6811-elf-addr2line
%attr(555,root,root) /usr/bin/m6811-elf-nm
%attr(555,root,root) /usr/bin/m6811-elf-strip
%attr(555,root,root) /usr/bin/m6811-elf-as
%attr(555,root,root) /usr/bin/m6811-elf-ld
%attr(555,root,root) /usr/bin/m6811-elf-readelf
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc11elf.x
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc11elf.xbn
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc11elf.xn
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc11elf.xr
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc11elf.xu
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc11elfb.x
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc11elfb.xbn
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc11elfb.xn
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc11elfb.xr
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc11elfb.xu
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc12elf.x
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc12elf.xbn
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc12elf.xn
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc12elf.xr
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc12elf.xu
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc12elfb.x
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc12elfb.xbn
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc12elfb.xn
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc12elfb.xr
%attr(444,root,root) /usr/m6811-elf/lib/ldscripts/m68hc12elfb.xu
%attr(444,root,root) /usr/man/man1/m6811-elf-ar.1*
%attr(444,root,root) /usr/man/man1/m6811-elf-c++filt.1*
%attr(444,root,root) /usr/man/man1/m6811-elf-nm.1*
%attr(444,root,root) /usr/man/man1/m6811-elf-objdump.1*
%attr(444,root,root) /usr/man/man1/m6811-elf-ranlib.1*
%attr(444,root,root) /usr/man/man1/m6811-elf-size.1*
%attr(444,root,root) /usr/man/man1/m6811-elf-strings.1*
%attr(444,root,root) /usr/man/man1/m6811-elf-strip.1*
%attr(444,root,root) /usr/man/man1/m6811-elf-objcopy.1*
%attr(444,root,root) /usr/man/man1/m6811-elf-addr2line.1*
%attr(444,root,root) /usr/man/man1/m6811-elf-readelf.1*
%attr(444,root,root) /usr/man/man1/m6811-elf-as.1*
%attr(444,root,root) /usr/man/man1/m6811-elf-ld.1*
%attr(555,root,root) %dir /usr/m6811-elf/doc
%attr(444,root,root) /usr/m6811-elf/doc/ar.html
%attr(444,root,root) /usr/m6811-elf/doc/c++filt.html
%attr(444,root,root) /usr/m6811-elf/doc/nm.html
%attr(444,root,root) /usr/m6811-elf/doc/objdump.html
%attr(444,root,root) /usr/m6811-elf/doc/ranlib.html
%attr(444,root,root) /usr/m6811-elf/doc/size.html
%attr(444,root,root) /usr/m6811-elf/doc/strings.html
%attr(444,root,root) /usr/m6811-elf/doc/strip.html
%attr(444,root,root) /usr/m6811-elf/doc/objcopy.html
%attr(444,root,root) /usr/m6811-elf/doc/addr2line.html
%attr(444,root,root) /usr/m6811-elf/doc/as.html
%attr(444,root,root) /usr/m6811-elf/doc/ld.html
%attr(444,root,root) /usr/m6811-elf/doc/readelf.html
%attr(444,root,root) /usr/m6811-elf/doc/index.html
%attr(444,root,root) /usr/m6811-elf/doc/as_*.html
%attr(444,root,root) /usr/m6811-elf/doc/binutils_*.html
%attr(444,root,root) /usr/m6811-elf/doc/ld_*.html
%attr(444,root,root) /usr/m6811-elf/doc/guide.html
%attr(444,root,root) /usr/m6811-elf/doc/hc11_*.html
%attr(444,root,root) /usr/m6811-elf/doc/*.png
%attr(444,root,root) /usr/m6811-elf/doc/*.jpg
%attr(444,root,root) /usr/m6811-elf/doc/*.css
%attr(444,root,root) /usr/m6811-elf/doc/COPYING

#
# Package installation.
#
%post
# Workarround for rpm Bug 75057 (fixed in rpm 4.2)
if test "T$RPM_INSTALL_PREFIX" = "T"; then
  RPM_INSTALL_PREFIX="/usr"
fi
# Create hard links to nm, strip, ar, ranlib, as, ld.
ln $RPM_INSTALL_PREFIX/bin/m6811-elf-nm $RPM_INSTALL_PREFIX/m6811-elf/bin/nm
ln $RPM_INSTALL_PREFIX/bin/m6811-elf-strip $RPM_INSTALL_PREFIX/m6811-elf/bin/strip
ln $RPM_INSTALL_PREFIX/bin/m6811-elf-ar $RPM_INSTALL_PREFIX/m6811-elf/bin/ar
ln $RPM_INSTALL_PREFIX/bin/m6811-elf-ranlib $RPM_INSTALL_PREFIX/m6811-elf/bin/ranlib
ln $RPM_INSTALL_PREFIX/bin/m6811-elf-as $RPM_INSTALL_PREFIX/m6811-elf/bin/as
ln $RPM_INSTALL_PREFIX/bin/m6811-elf-ld $RPM_INSTALL_PREFIX/m6811-elf/bin/ld
ln $RPM_INSTALL_PREFIX/bin/m6811-elf-size $RPM_INSTALL_PREFIX/m6811-elf/bin/size
ln $RPM_INSTALL_PREFIX/bin/m6811-elf-objdump $RPM_INSTALL_PREFIX/m6811-elf/bin/objdump
ln $RPM_INSTALL_PREFIX/bin/m6811-elf-objcopy $RPM_INSTALL_PREFIX/m6811-elf/bin/objcopy
ln $RPM_INSTALL_PREFIX/bin/m6811-elf-strings $RPM_INSTALL_PREFIX/m6811-elf/bin/strings
ln $RPM_INSTALL_PREFIX/bin/m6811-elf-addr2line $RPM_INSTALL_PREFIX/m6811-elf/bin/addr2line
ln $RPM_INSTALL_PREFIX/bin/m6811-elf-c++filt $RPM_INSTALL_PREFIX/m6811-elf/bin/c++filt
ln $RPM_INSTALL_PREFIX/bin/m6811-elf-readelf $RPM_INSTALL_PREFIX/m6811-elf/bin/readelf

%preun
# Workarround for rpm Bug 75057 (fixed in rpm 4.2)
if test "T$RPM_INSTALL_PREFIX" = "T"; then
  RPM_INSTALL_PREFIX="/usr"
fi
# Remove all the hard links we created.
rm -f $RPM_INSTALL_PREFIX/m6811-elf/bin/nm
rm -f $RPM_INSTALL_PREFIX/m6811-elf/bin/strip
rm -f $RPM_INSTALL_PREFIX/m6811-elf/bin/ar
rm -f $RPM_INSTALL_PREFIX/m6811-elf/bin/ranlib
rm -f $RPM_INSTALL_PREFIX/m6811-elf/bin/as
rm -f $RPM_INSTALL_PREFIX/m6811-elf/bin/ld
rm -f $RPM_INSTALL_PREFIX/m6811-elf/bin/size
rm -f $RPM_INSTALL_PREFIX/m6811-elf/bin/objdump
rm -f $RPM_INSTALL_PREFIX/m6811-elf/bin/objcopy
rm -f $RPM_INSTALL_PREFIX/m6811-elf/bin/strings
rm -f $RPM_INSTALL_PREFIX/m6811-elf/bin/addr2line
rm -f $RPM_INSTALL_PREFIX/m6811-elf/bin/c++filt
rm -f $RPM_INSTALL_PREFIX/m6811-elf/bin/readelf

%clean
#echo "Cleaning up"
#rm -rf /build/binutils-inst
